@@ -1,39 +1,38 @@
 // -*- c++ -*-
-/* $Id: ustring.cc 652 2008-04-13 10:52:16Z murrayc $ */
+/* $Id$ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <glibmmconfig.h>
 #include <glibmm/ustring.h>
 #include <glibmm/convert.h>
 #include <glibmm/error.h>
 #include <glibmm/utility.h>
-#include <glib.h>
 
 #include <algorithm>
 #include <iostream>
 #include <cstring>
-
-#include <config.h>
-#include <glibmmconfig.h>
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
 # include <stdexcept>
 #endif
-GLIBMM_USING_STD(find)
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 namespace
 {
